@@ -12,6 +12,7 @@ lazy_static! {
             let mut m: HashMap<String, f64> = vec![
                 ("1INCH/USDT", 1f64),
                 ("AAVE/USDT", 0.01f64),
+                ("ACH/USDT", 11f64),
                 ("ADA/USDT", 10f64),
                 ("ALGO/USDT", 10f64),
                 ("ALICE/USDT", 0.1f64),
@@ -24,10 +25,12 @@ lazy_static! {
                 ("AR/USDT", 0.1f64),
                 ("ATOM/USDT", 1f64),
                 ("AVAX/USDT", 1f64),
+                ("AXS/USDT", 0.1f64),
                 ("BADGER/USDT", 0.1f64),
                 ("BAKE/USDT", 0.1f64),
                 ("BAND/USDT", 0.1f64),
                 ("BAT/USDT", 10f64),
+                ("BCD/USDT", 0.1f64),
                 ("BCH/USDT", 0.01f64),
                 ("BCHA/USDT", 0.1f64),
                 ("BEAM/USDT", 10f64),
@@ -37,13 +40,17 @@ lazy_static! {
                 ("BTC/USDT", 0.0001f64),
                 ("BTM/USDT", 10f64),
                 ("BTS/USDT", 100f64),
+                ("BZZ/USDT", 0.1f64),
+                ("C98/USDT", 1f64),
                 ("CAKE/USDT", 0.1f64),
                 ("CFX/USDT", 10f64),
                 ("CHR/USDT", 10f64),
                 ("CHZ/USDT", 100f64),
                 ("CKB/USDT", 100f64),
+                ("CLV/USDT", 1f64),
                 ("COMP/USDT", 0.01f64),
                 ("CONV/USDT", 10f64),
+                ("COTI/USDT", 1f64),
                 ("CRU/USDT", 0.01f64),
                 ("CRV/USDT", 0.1f64),
                 ("CVC/USDT", 10f64),
@@ -61,6 +68,8 @@ lazy_static! {
                 ("FIL6/USDT", 0.1f64),
                 ("FLOW/USDT", 0.1f64),
                 ("FRONT/USDT", 1f64),
+                ("FTT/USDT", 0.01f64),
+                ("GITCOIN/USDT", 0.1f64),
                 ("GRIN/USDT", 10f64),
                 ("GRT/USDT", 10f64),
                 ("HBAR/USDT", 10f64),
@@ -70,6 +79,7 @@ lazy_static! {
                 ("IRIS/USDT", 10f64),
                 ("JST/USDT", 100f64),
                 ("KAVA/USDT", 1f64),
+                ("KEEP/USDT", 1f64),
                 ("KSM/USDT", 0.1f64),
                 ("LINA/USDT", 10f64),
                 ("LINK/USDT", 1f64),
@@ -80,6 +90,7 @@ lazy_static! {
                 ("LUNA/USDT", 1f64),
                 ("MASK/USDT", 0.1f64),
                 ("MATIC/USDT", 10f64),
+                ("MINA/USDT", 0.1f64),
                 ("MKR/USDT", 0.001f64),
                 ("MTL/USDT", 0.1f64),
                 ("NEAR/USDT", 1f64),
@@ -93,14 +104,17 @@ lazy_static! {
                 ("PEARL/USDT", 0.001f64),
                 ("PERP/USDT", 0.1f64),
                 ("POLS/USDT", 1f64),
+                ("POLY/USDT", 1f64),
                 ("POND/USDT", 10f64),
                 ("PRIV/USDT", 0.001f64),
                 ("QTUM/USDT", 1f64),
                 ("RNDR/USDT", 1f64),
                 ("ROSE/USDT", 100f64),
+                ("RVN/USDT", 10f64),
                 ("SERO/USDT", 10f64),
                 ("SHIB/USDT", 10000f64),
                 ("SKL/USDT", 10f64),
+                ("SLP/USDT", 1f64),
                 ("SNX/USDT", 0.1f64),
                 ("SOL/USDT", 1f64),
                 ("SRM/USDT", 1f64),
@@ -111,11 +125,14 @@ lazy_static! {
                 ("SXP/USDT", 1f64),
                 ("TFUEL/USDT", 10f64),
                 ("THETA/USDT", 1f64),
+                ("TLM/USDT", 1f64),
+                ("TRIBE/USDT", 1f64),
                 ("TRU/USDT", 10f64),
                 ("TRX/USDT", 100f64),
                 ("UNI/USDT", 1f64),
                 ("VET/USDT", 100f64),
                 ("WAVES/USDT", 1f64),
+                ("WAXP/USDT", 1f64),
                 ("WSB/USDT", 0.001f64),
                 ("XAUG/USDT", 0.001f64),
                 ("XCH/USDT", 0.001f64),
@@ -127,6 +144,7 @@ lazy_static! {
                 ("XVS/USDT", 0.01f64),
                 ("YFI/USDT", 0.0001f64),
                 ("YFII/USDT", 0.001f64),
+                ("YGG/USDT", 1f64),
                 ("ZEC/USDT", 0.01f64),
                 ("ZEN/USDT", 0.1f64),
                 ("ZIL/USDT", 10f64),
