@@ -19,6 +19,7 @@ lazy_static! {
                 ("ANT/USDT", 1f64),
                 ("ATOM/USDT", 1f64),
                 ("AVAX/USDT", 1f64),
+                ("AXS/USDT", 0.1f64),
                 ("BADGER/USDT", 0.1f64),
                 ("BAL/USDT", 0.1f64),
                 ("BAND/USDT", 1f64),
@@ -29,10 +30,12 @@ lazy_static! {
                 ("BTC/USDT", 0.01f64),
                 ("BTM/USDT", 100f64),
                 ("BTT/USDT", 10000f64),
+                ("BZZ/USDT", 0.1f64),
                 ("CFX/USDT", 10f64),
                 ("CHZ/USDT", 10f64),
                 ("COMP/USDT", 0.1f64),
                 ("CONV/USDT", 10f64),
+                ("CQT/USDT", 1f64),
                 ("CRO/USDT", 10f64),
                 ("CRV/USDT", 1f64),
                 ("CSPR/USDT", 1f64),
@@ -41,6 +44,7 @@ lazy_static! {
                 ("DOGE/USDT", 1000f64),
                 ("DORA/USDT", 0.1f64),
                 ("DOT/USDT", 1f64),
+                ("EFI/USDT", 1f64),
                 ("EGLD/USDT", 0.1f64),
                 ("ENJ/USDT", 1f64),
                 ("EOS/USDT", 10f64),
@@ -66,6 +70,7 @@ lazy_static! {
                 ("MANA/USDT", 10f64),
                 ("MASK/USDT", 1f64),
                 ("MATIC/USDT", 10f64),
+                ("MINA/USDT", 1f64),
                 ("MIR/USDT", 1f64),
                 ("MKR/USDT", 0.01f64),
                 ("NEAR/USDT", 10f64),
@@ -80,6 +85,7 @@ lazy_static! {
                 ("SAND/USDT", 10f64),
                 ("SC/USDT", 100f64),
                 ("SHIB/USDT", 1000000f64),
+                ("SLP/USDT", 10f64),
                 ("SNX/USDT", 1f64),
                 ("SOL/USDT", 1f64),
                 ("SRM/USDT", 1f64),
@@ -94,6 +100,7 @@ lazy_static! {
                 ("UMA/USDT", 0.1f64),
                 ("UNI/USDT", 1f64),
                 ("WAVES/USDT", 1f64),
+                ("WNCG/USDT", 1f64),
                 ("WNXM/USDT", 0.1f64),
                 ("XCH/USDT", 0.01f64),
                 ("XEM/USDT", 10f64),
@@ -103,6 +110,7 @@ lazy_static! {
                 ("XTZ/USDT", 1f64),
                 ("YFI/USDT", 0.0001f64),
                 ("YFII/USDT", 0.001f64),
+                ("YGG/USDT", 1f64),
                 ("ZEC/USDT", 0.1f64),
                 ("ZEN/USDT", 1f64),
                 ("ZIL/USDT", 100f64),
